@@ -27,7 +27,7 @@ def root_dir():
 
 def add_root_dir_to_path(root_dir):
     path = os.path.abspath(os.path.join(os.path.dirname(__file__), root_dir))
-    print(path)
+    # print(path)
     if path not in sys.path:
         sys.path.insert(1, path)
 
@@ -65,21 +65,21 @@ def pytest_configure(config):
     config.addinivalue_line("markers", "source: mark test as a source function")
 
 
-def pytest_collection_modifyitems(config, items):
-    """ This function makes pytest skip the source or destination tests, depending if the --source or --destination
-    flag is not present. """
-    if not config.getoption("--source"):
-        # makes the test print the reason the test was skipped
-        skip_source = pytest.mark.skip(reason="need --source option to run")
-        for item in items:
-            if "source" in item.keywords:
-                item.add_marker(skip_source)
-
-    if not config.getoption("--destination"):
-        skip_destination = pytest.mark.skip(reason="need --destination option to run")
-        for item in items:
-            if "destination" in item.keywords:
-                item.add_marker(skip_destination)
+# def pytest_collection_modifyitems(config, items):
+# """ This function makes pytest skip the source or destination tests, depending if the --source or --destination
+# flag is not present. """
+# if not config.getoption("--source"):
+#     # makes the test print the reason the test was skipped
+#     skip_source = pytest.mark.skip(reason="need --source option to run")
+#     for item in items:
+#         if "source" in item.keywords:
+#             item.add_marker(skip_source)
+#
+# if not config.getoption("--destination"):
+#     skip_destination = pytest.mark.skip(reason="need --destination option to run")
+#     for item in items:
+#         if "destination" in item.keywords:
+#             item.add_marker(skip_destination)
 
 
 @pytest.fixture(scope="session")
@@ -117,6 +117,26 @@ def bad_credentials(env):
     return res
 
 
+@pytest.fixture(scope="session")
+def filtered_column_nm(env):
+    return env["FILTERED_COLUMN_NM"]
+
+
+@pytest.fixture(scope="session")
+def filtered_column_date_format(env):
+    return env["FILTERED_COLUMN_DATE_FORMAT"]
+
+
+@pytest.fixture(scope="session")
+def custom_date_start_val():
+    return "1941-03-26"
+
+
+@pytest.fixture(scope="session")
+def custom_date_end_val():
+    return "2000-01-01"
+
+
 @pytest.fixture(scope="session")
 def connector(connector_class, good_credentials):
     connector = connector_class.Connector(good_credentials)
